@@ -1,8 +1,13 @@
-package MySimpleProcess;
+package t::lib::MySimpleProcess;
 
 use strict;
-use base 'Process',
-         'Process::Storable';
+use Process ();
+
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '0.01';
+	@ISA     = 'Process';
+}
 
 sub new {
 	my $class = shift;
@@ -19,9 +24,6 @@ sub prepare {
 
 sub run {
 	my $self = shift;
-	foreach my $key ( sort keys %$self ) {
-		print STDERR "$key=$self->{$key}\n";
-	}
 	unless ( $self->{run} ) {
 		$self->{run} = 1;
 	}
